@@ -10,7 +10,7 @@ log = logging.getLogger(__name__)
 
 
 class Sensor(BaseDevice):
-    """Represent Alarm.com system element."""
+    """Represent Alarm.com sensor element."""
 
     class DeviceState(Enum):
         """Enum of sensor states."""
@@ -49,8 +49,3 @@ class Sensor(BaseDevice):
         PANEL_GLASS_BREAK_DETECTOR = 83
         PANEL_IMAGE_SENSOR = 68
         MOBILE_PHONE = 69
-
-    @property
-    def read_only(self) -> None:
-        """Non-actionable object."""
-        return
