@@ -1,24 +1,21 @@
 """Configuration option extensions."""
 from __future__ import annotations
 
-from abc import ABC
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 import asyncio
 from dataclasses import dataclass
-from enum import auto
-from enum import Enum
+from enum import Enum, auto
 import logging
 import re
 from typing import Any
 
 import aiohttp
-from bs4 import BeautifulSoup
-from bs4 import Tag
+from bs4 import BeautifulSoup, Tag
+
 from pyalarmdotcomajax import const as c
 from pyalarmdotcomajax.errors import UnexpectedDataStructure
 
-from .helpers import ExtendedEnumMixin
-from .helpers import extract_field_value
+from .helpers import ExtendedEnumMixin, extract_field_value
 
 log = logging.getLogger(__name__)
 
@@ -316,9 +313,8 @@ class CameraSkybellControllerExtension(ControllerExtension):
         try:
             for config_id in additional_camera_config_ids:
                 # Build payload to request config page for next camera
-                postback_form_data = current_form_data.raw_attribs
 
-                if not postback_form_data:
+                if not (postback_form_data := current_form_data.raw_attribs):
                     raise UnexpectedDataStructure
 
                 postback_form_data["__EVENTTARGET"] = "ctl00$phBody$CamSelector$ddlCams"
@@ -363,8 +359,10 @@ class CameraSkybellControllerExtension(ControllerExtension):
         # For volume adjustable chimes (outdoor),  When on, either 1 for low, 2 for medium, 3 for high, or 0 for off.
 
         log.debug(
-            "CameraSkybellControllerExtension -> submit_change(): Requested change for"
-            " %s: %s to %s.",
+            (
+                "CameraSkybellControllerExtension -> submit_change(): Requested change"
+                " for %s: %s to %s."
+            ),
             camera_name,
             slug,
             new_value,
@@ -516,8 +514,10 @@ class CameraSkybellControllerExtension(ControllerExtension):
         debug_payload.pop("__VIEWSTATE")
 
         log.debug(
-            "======= POST PAYLOAD - BEGIN =======\n\n%s\n\n======= POST"
-            " PAYLOAD - END =======",
+            (
+                "======= POST PAYLOAD - BEGIN =======\n\n%s\n\n======= POST"
+                " PAYLOAD - END ======="
+            ),
             debug_payload,
         )
 
@@ -549,9 +549,7 @@ class CameraSkybellControllerExtension(ControllerExtension):
 
         return camera_return_data.settings[slug]
 
-    def _build_submit_payload(  # pylint: disable = no-self-use
-        self, response_data: dict
-    ) -> dict:
+    def _build_submit_payload(self, response_data: dict) -> dict:
         """Build POST for new setting submission or for getting other camera data."""
 
         # Pre-populate static fields.
@@ -591,9 +589,7 @@ class CameraSkybellControllerExtension(ControllerExtension):
 
         try:
             for field_name in self._FORM_FIELDS_BYPASSABLE:
-                field = tree.find(attrs={"name": field_name})
-
-                if not field:
+                if not (field := tree.find(attrs={"name": field_name})):
                     raw_attribs[field_name] = ""
                 else:
                     try:
