@@ -2,20 +2,17 @@
 
 # pylint: disable = redefined-outer-name
 
-from collections.abc import AsyncGenerator
-from collections.abc import Generator
+from collections.abc import AsyncGenerator, Generator
 
 import aiohttp
 from aioresponses import aioresponses
-from pyalarmdotcomajax import AlarmController
-from pyalarmdotcomajax import const as c
-from pyalarmdotcomajax.devices import DEVICE_URLS
-from pyalarmdotcomajax.devices import DeviceType
-from pyalarmdotcomajax.extensions import CameraSkybellControllerExtension
 import pytest
 
-from .responses import get_http_body_html
-from .responses import get_http_body_json
+from pyalarmdotcomajax import AlarmController, const as c
+from pyalarmdotcomajax.devices import DEVICE_URLS, DeviceType
+from pyalarmdotcomajax.extensions import CameraSkybellControllerExtension
+
+from .responses import get_http_body_html, get_http_body_json
 
 
 @pytest.fixture  # type: ignore
@@ -86,6 +83,14 @@ def all_base_ok_responses(response_mocker: aioresponses) -> None:
         body=get_http_body_json("garage_door_ok"),
     )
 
+    response_mocker.get(
+        url=DEVICE_URLS["supported"][DeviceType.GATE]["endpoint"].format(
+            c.URL_BASE, ""
+        ),
+        status=200,
+        body=get_http_body_json("gate_ok"),
+    )
+
     response_mocker.get(
         url=DEVICE_URLS["supported"][DeviceType.IMAGE_SENSOR]["endpoint"].format(
             c.URL_BASE, ""
@@ -142,6 +147,14 @@ def all_base_ok_responses(response_mocker: aioresponses) -> None:
         body=get_http_body_json("thermostat_ok"),
     )
 
+    response_mocker.get(
+        url=DEVICE_URLS["supported"][DeviceType.WATER_SENSOR]["endpoint"].format(
+            c.URL_BASE, ""
+        ),
+        status=200,
+        body=get_http_body_json("water_sensor_ok"),
+    )
+
 
 @pytest.fixture  # type: ignore
 def all_extension_ok_responses(response_mocker: aioresponses) -> None:
@@ -233,6 +246,14 @@ def all_base_ok_camera_403(response_mocker: aioresponses) -> None:
         body=get_http_body_json("garage_door_ok"),
     )
 
+    response_mocker.get(
+        url=DEVICE_URLS["supported"][DeviceType.GATE]["endpoint"].format(
+            c.URL_BASE, ""
+        ),
+        status=200,
+        body=get_http_body_json("gate_ok"),
+    )
+
     response_mocker.get(
         url=DEVICE_URLS["supported"][DeviceType.IMAGE_SENSOR]["endpoint"].format(
             c.URL_BASE, ""
@@ -289,6 +310,14 @@ def all_base_ok_camera_403(response_mocker: aioresponses) -> None:
         body=get_http_body_json("thermostat_ok"),
     )
 
+    response_mocker.get(
+        url=DEVICE_URLS["supported"][DeviceType.WATER_SENSOR]["endpoint"].format(
+            c.URL_BASE, ""
+        ),
+        status=200,
+        body=get_http_body_json("water_sensor_ok"),
+    )
+
 
 @pytest.fixture  # type: ignore
 def all_base_ok_camera_404(response_mocker: aioresponses) -> None:
@@ -337,6 +366,14 @@ def all_base_ok_camera_404(response_mocker: aioresponses) -> None:
         body=get_http_body_json("garage_door_ok"),
     )
 
+    response_mocker.get(
+        url=DEVICE_URLS["supported"][DeviceType.GATE]["endpoint"].format(
+            c.URL_BASE, ""
+        ),
+        status=200,
+        body=get_http_body_json("gate_ok"),
+    )
+
     response_mocker.get(
         url=DEVICE_URLS["supported"][DeviceType.IMAGE_SENSOR]["endpoint"].format(
             c.URL_BASE, ""
@@ -392,3 +429,11 @@ def all_base_ok_camera_404(response_mocker: aioresponses) -> None:
         status=200,
         body=get_http_body_json("thermostat_ok"),
     )
+
+    response_mocker.get(
+        url=DEVICE_URLS["supported"][DeviceType.WATER_SENSOR]["endpoint"].format(
+            c.URL_BASE, ""
+        ),
+        status=200,
+        body=get_http_body_json("water_sensor_ok"),
+    )
