@@ -6,9 +6,11 @@ import json
 
 import aiohttp
 from deepdiff import DeepDiff
+import pytest
+
 from pyalarmdotcomajax import AlarmController
 from pyalarmdotcomajax.devices import DeviceType
-import pytest
+
 from tests.responses import get_http_body_json
 
 
@@ -31,6 +33,7 @@ def test_property__initial_state(adc_client: AlarmController) -> None:
     assert not adc_client.lights
     assert not adc_client.thermostats
     assert not adc_client.cameras
+    assert not adc_client.water_sensors
 
 
 @pytest.mark.asyncio  # type: ignore
@@ -43,7 +46,6 @@ async def test__async_get_items_and_subordinates__sensors(
     items = await adc_client._async_get_items_and_subordinates(DeviceType.SENSOR)
 
     for rsp_device, _ in items:
-
         src_match = {}
 
         for src_device in json.loads(get_http_body_json("sensor_ok")).get("data", {}):
@@ -86,4 +88,5 @@ async def test___async_update__ok(
     assert adc_client.image_sensors
     assert adc_client.lights
     assert adc_client.thermostats
-    # assert adc_client.cameras
+    assert adc_client.cameras
+    assert adc_client.water_sensors
